@@ -4,7 +4,7 @@ from .python3_compat import iteritems
 class Call(object):
     def __init__(self, *args, **kwargs):
         super(Call, self).__init__()
-        self._key = frozenset([args, frozenset(kwargs.iteritems())])
+        self._key = (args, kwargs)
         self.args = args
         self.kwargs = kwargs
     def __eq__(self, other):
@@ -12,7 +12,7 @@ class Call(object):
     def __ne__(self, other):
         return not (self == other)
     def __hash__(self):
-        return hash(self._key)
+        raise TypeError("Call objects are unhashable")
     def __repr__(self):
         args_item_strs = map(repr, self.args)
         kwargs_item_strs = ("{0}={1!r}".format(key, value) for key, value in iteritems(self.kwargs))
@@ -20,5 +20,4 @@ class Call(object):
     def __nonzero__(self):
         return bool(self.args) or bool(self.kwargs)
 
-
 EMPTY_CALL = Call()
